@@ -13,18 +13,18 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
-#include <koApplication.h>
-#include <koDocument.h>
-#include <koMainWindow.h>
+#include <KoApplication.h>
+#include <KoDocument.h>
+#include <KoMainWindow.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <dcopclient.h>
 #include "example_aboutdata.h"
-
+#include <koffice_export.h>
 
 static const KCmdLineOptions options[]=
 {
@@ -32,7 +32,7 @@ static const KCmdLineOptions options[]=
 	KCmdLineLastOption
 };
 
-int main( int argc, char **argv )
+extern "C" EXAMPLE_EXPORT int kdemain( int argc, char **argv )
 {
     KCmdLineArgs::init( argc, argv, newExampleAboutData() );
     KCmdLineArgs::addCmdLineOptions( options );
@@ -42,3 +42,4 @@ int main( int argc, char **argv )
 	return 1;
     return app.exec();
 }
+
