@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Ariya Hidayat <ariya@kde.org>
+   Copyright (C) 2003-2006 Ariya Hidayat <ariya@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -13,15 +13,17 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef EXCELIMPORT_H
 #define EXCELIMPORT_H
 
-#include <koFilter.h>
-#include <koStore.h>
+#include <KoFilter.h>
+#include <KoStore.h>
+
+#include <qcstring.h>
 
 class ExcelImport : public KoFilter {
 
@@ -30,9 +32,14 @@ class ExcelImport : public KoFilter {
 public:
 
     ExcelImport ( QObject *parent, const char* name, const QStringList& );
-    virtual ~ExcelImport() {}
+    virtual ~ExcelImport();
 
     virtual KoFilter::ConversionStatus convert( const QCString& from, const QCString& to );
+
+private:
+  class Private;
+  Private* d;
+
 };
 
 #endif // EXCELIMPORT_H
