@@ -14,15 +14,15 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VSHAPECMD_H__
 #define __VSHAPECMD_H__
 
 #include "vcommand.h"
-
+#include <koffice_export.h>
 class VPath;
 
 /*
@@ -31,7 +31,7 @@ class VPath;
  * execution() the shape will be added to the document and selected, upon undoing
  * it will be set to the deleted state.
  */
-class VShapeCmd : public VCommand
+class KARBONCOMMAND_EXPORT VShapeCmd : public VCommand
 {
 public:
 	VShapeCmd( VDocument* doc, const QString& name, VPath* shape, const QString& icon = "14_polygon" );
