@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VLAYER_H__
@@ -36,7 +36,19 @@ class DCOPObject;
 class KARBONBASE_EXPORT VLayer : public VGroup
 {
 public:
+	/**
+	 * Constructs a new layer object that is child of parent and has the given state.
+	 *
+	 * @param parent the new object's parent
+	 * @param state the new object's state
+	 */
 	VLayer( VObject* parent, VState state = normal );
+
+	/**
+	 * Copy constructor.
+	 *
+	 * @param layer the layer to copy properties from
+	 */
 	VLayer( const VLayer& layer );
 
 	virtual ~VLayer();
@@ -45,27 +57,61 @@ public:
 	virtual void draw( VPainter *painter, const KoRect* rect = 0L ) const;
 
 	virtual void save( QDomElement& element ) const;
-	virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const;
+	virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles, int &index ) const;
 	virtual void load( const QDomElement& element );
 
 	virtual VLayer* clone() const;
 
 	virtual void accept( VVisitor& visitor );
 
-
+	/**
+	 * Moves the object to the top of the list.
+	 *
+	 * When the object is at the top this method has no effect.
+	 *
+	 * @param object the object to move
+	 */
 	void bringToFront( const VObject& object );
 
-	/// moves the object one step up the list.
-	/// When the object is at the top this method has no effect.
+	/** 
+	 * Moves the object one step up the list.
+	 *
+	 * When the object is at the top this method has no effect.
+	 *
+	 * @param object the object to move
+	 */
 	void upwards( const VObject& object );
 
-	/// moves the object one step down the list.
-	/// When the object is at the bottom this method has no effect.
+	/** 
+	 * Moves the object one step down the list.
+	 *
+	 * When the object is at the bottom this method has no effect.
+	 *
+	 * @param object the object to move
+	 */
 	void downwards( const VObject& object );
 
+	/** 
+	 * Moves the object to the end of the list.
+	 *
+	 * When the object is at the bottom this method has no effect.
+	 *
+	 * @param object the object to move
+	 */
 	void sendToBack( const VObject& object );
 
+	/**
+	 * Selects or unselects the layer 
+	 *
+	 * @param state the new selection state
+	 */
 	void setSelected( bool state ) { setState( state ? VObject::selected : VObject::normal ); }
+
+	/**
+	 * Returns the selection state of the layer
+	 *
+	 * @return the actual selection state
+	 */
 	bool selected() { return state() == VObject::selected; }
 };
 
