@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VTYPEBUTTONBOX_H__
@@ -29,12 +29,11 @@ class VTypeButtonBox : public QHButtonGroup
 	Q_OBJECT
 
 public:
-	enum buttonType
- 	{
-		none = 0,
-		solid = 1,
+	enum buttonType {
+		none     = 0,
+		solid    = 1,
 		gradient = 2,
-		pattern = 3
+		pattern  = 3
  	};
 
 	VTypeButtonBox( KarbonPart *part, QWidget* parent = 0L, const char* name = 0L );
@@ -46,8 +45,9 @@ public slots:
 	void setStroke();
 
 private:
-	KarbonPart *m_part;
-	bool m_isStrokeManipulator;
+	KarbonPart  *m_part;
+	bool         m_isStrokeManipulator;
+
 	void manipulateFills( int id );
 	void manipulateStrokes( int id );
 };
