@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@gmx.at>
    Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
-   Copyright (C) 2004-2005 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -272,7 +272,7 @@ class KFORMEDITOR_EXPORT Form : public QObject
 		void updateTabStopsOrder();
 
 		/*! Adds the widget at the end of tabstops list. Called on widget creation. */
-		void addWidgetToTabStops(ObjectTreeItem *c);
+		void addWidgetToTabStops(ObjectTreeItem *it);
 
 		/*! \return True if the Form automatically handles tab stops. */
 		bool autoTabStops() const { return d->autoTabstops; }
@@ -285,10 +285,13 @@ class KFORMEDITOR_EXPORT Form : public QObject
 		void setAutoTabStops(bool autoTab) { d->autoTabstops = autoTab;}
 
 		/*! Tells the Form to reassign the tab stops because the widget layout has changed
-		(called for example before saving or displaying the tab order dialog) */
+		 (called for example before saving or displaying the tab order dialog).
+		 Automatically sorts widget from the top-left to bottom-right corner.
+		 Widget can be grouped with containers. In paticular, for tab widgets,
+		 child widgets should ordered by parent tab's order. */
 		void autoAssignTabStops();
 
-#ifdef KEXI_SHOW_DEBUG_ACTIONS
+#ifdef KEXI_DEBUG_GUI
 		//! For debugging purposes
 		QString m_recentlyLoadedUICode;
 #endif
@@ -324,8 +327,10 @@ class KFORMEDITOR_EXPORT Form : public QObject
 		 If \a add is true, the formerly selected widget is still selected, 
 		 and the new one is just added. If false, \a selected replace the actually selected widget.
 		 The form widget is always selected alone.
-		 */
-		void setSelectedWidget(QWidget *selected, bool add=false, bool dontRaise=false);
+		 \a moreWillBeSelected indicates whether more widgets will be selected soon
+		 (so for multiselection we should not update the property pane before the last widget is selected) */
+		void setSelectedWidget(QWidget *selected, bool add=false, bool dontRaise=false,
+			bool moreWillBeSelected = false);
 
 		/*! Unselects the widget \a w. Te widget is removed from the Cntainer 's list
 		and its resizeHandle is removed. */
@@ -355,11 +360,11 @@ class KFORMEDITOR_EXPORT Form : public QObject
 		void slotFormRestored();
 
 	signals:
-		/*! This signal is emitted when user selects a new widget, to update both
-		   Property Editor and ObjectTreeView.
-		   \a w is the newly selected widget.
+		/*! This signal is emitted by setSelectedWidget() when user selects a new widget, 
+		 to update both Property Editor and ObjectTreeView.
+		 \a w is the newly selected widget.
 		  */
-		void selectionChanged(QWidget *w, bool add);
+		void selectionChanged(QWidget *w, bool add, bool moreWillBeSelected = false);
 
 		/*! This signal is emitted when a new widget is created, to update ObjectTreeView.
 		 \a it is the ObjectTreeItem representing this new widget.
