@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@gmx.at>
    Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
-   Copyright (C) 2004-2005 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004-2006 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KFORMDESIGNERWIDGETFACTORY_H
@@ -29,7 +29,7 @@
 #include <qpopupmenu.h>
 #include <qasciidict.h>
 
-#include <tristate.h>
+#include <kexiutils/tristate.h>
 
 // class QPixmap;
 template<class type> class QValueVector;
@@ -40,17 +40,24 @@ class QDomElement;
 class QDomDocument;
 class QVariant;
 class QListView;
-class KLineEdit;
-class KTextEdit;
 class KActionCollection;
-class KexiPropertyBuffer;
+class KTextEdit;
+class KLineEdit;
+class KXMLGUIClient;
+
+namespace KoProperty {
+	class Set;
+}
 
 namespace KFormDesigner {
 
 class WidgetFactory;
+class WidgetLibrary;
 class Container;
 class ResizeHandleSet;
 class ObjectTreeItem;
+class WidgetPropertySet;
+class Form;
 
 /**
  * This class holds properties of widget classes provided by a factory.
@@ -93,7 +100,7 @@ class KFORMEDITOR_EXPORT WidgetInfo
 		void setDescription(const QString &desc) { m_desc = desc;}
 
 		/*! Sets the C++ include file corresponding to this class,
-		 that uic will need to add when creating the file. */
+		 that uic will need to add when creating the file. You don't have to set this for Qt std widgets.*/
 		void setIncludeFileName(const QString &name) { m_include = name;}
 
 		/*! Sets alternate names for this class.
@@ -130,7 +137,7 @@ class KFORMEDITOR_EXPORT WidgetInfo
 
 		/*! Sets autoSync flag for property \a propertyName.
 		 This allows to override autoSync flag for certain widget's property, because
-		 e.g. KexiPropertyEditor can have autoSync flag set to false or true, but
+		 e.g. KoProperty::Editor can have autoSync flag set to false or true, but
 		 not all properties have to comply with that.
 		 \a flag equal to cancelled value means there is no overriding (the default). */
 		void setAutoSyncForProperty(const char *propertyName, tristate flag);
@@ -143,6 +150,16 @@ class KFORMEDITOR_EXPORT WidgetInfo
 
 		WidgetInfo* inheritedClass() const { return m_inheritedClass; }
 
+		/*! Sets custom type \a type for property \a propertyName. 
+		 This allows to override default type, especially when custom property 
+		 and custom property editor item has to be used. */
+		void setCustomTypeForProperty(const char *propertyName, int type);
+
+		/*! \return custom type for property \a propertyName. If no specific custom type has been assigned,
+		 KoProperty::Auto is returned. 
+		 @see setCustomTypeForProperty() */
+		int customTypeForProperty(const char *propertyName) const;
+
 	protected:
 		QCString m_parentFactoryName, m_inheritedClassName; //!< Used for inheriting widgets between factories
 		WidgetInfo* m_inheritedClass;
@@ -159,6 +176,7 @@ class KFORMEDITOR_EXPORT WidgetInfo
 		QString m_saveName;
 		QGuardedPtr<WidgetFactory> m_factory;
 		QAsciiDict<char> *m_propertiesWithDisabledAutoSync;
+		QMap<QCString,int> *m_customTypesForProperty;
 
 	friend class WidgetLibrary;
 };
@@ -177,9 +195,10 @@ class KFORMEDITOR_EXPORT WidgetInfo
   You can use createMenuActions() to add custom items in widget's context menu. The previewWidget()
   is called when the Form gets in Preview mode, and you have a last opportunity to remove all editing-related
   stuff (see eg \ref Spring class).\n
-  You can also choose which properties to show in the Property Editor. By default, all properties are shown,
-  but you can hide some using isPropertyVisible(). To add new properties, just define new Q_PROPERTY
-  in widget class definition.\n \n
+  You can also choose which properties to show in the Property Editor. 
+  By default, most all properties are shown (see implementation for details),
+  but you can hide some reimplementing isPropertyVisibleInternal() (don't forget to call superclass' method)
+  To add new properties, just define new Q_PROPERTY in widget class definition.\n \n
 
   <b>Inline editing</b>\n
   KFormDesigner allow you to edit the widget's contents inside Form, without using a dialog.
@@ -203,6 +222,35 @@ class KFORMEDITOR_EXPORT WidgetInfo
    save combo box or listview contents (see saveSpecialProperty() and
   readSpecialProperty()). \n \n
 
+  <b>Special internal properties</b>\n
+  Use void setInternalProperty(const QCString& classname, const QCString& property, const QString& value);
+  to set values of special internal properties.
+  Currently these properties are used for customizing popup menu items used for orientation selection.
+  Customization for class ClassName should look like:
+  <code> void setInternalProperty("ClassName", "orientationSelectionPopup", "myicon"); </code>
+  Available internal properties:
+  * "orientationSelectionPopup" - set it to "1" if you want a given class to offer orientation selection,
+     so orientation selection popup will be displayed when needed.
+  * "orientationSelectionPopup:horizontalIcon" - sets a name of icon for "Horizontal" item
+    for objects of class 'ClassName'. Set this property only for classes supporting orientations.
+  * "orientationSelectionPopup:verticalIcon" - the same for "Vertical" item.
+    Set this property only for classes supporting orientations.
+  * "orientationSelectionPopup:horizontalText" - sets a i18n'd text for "Horizontal" item
+    for objects of class 'ClassName', e.g. i18n("Insert Horizontal Line").
+    Set this property only for classes supporting orientations.
+  * "orientationSelectionPopup:verticalText" - the same for "Vertical" item,
+    e.g. i18n("Insert Vertical Line"). Set this property only for classes supporting orientations.
+  * "dontStartEditingOnInserting" - if not empty, WidgetFactory::startEditing() will not be executed upon
+    widget inseting by a user.
+  * "forceShowAdvancedProperty:{propertyname}" - set it to "1" for "{propertyname}" advanced property 
+    if you want to force it to be visible even if WidgetLibrary::setAdvancedPropertiesVisible(false) 
+    has been called. For example, setting "forceShowAdvancedProperty:pixmap" to "1" 
+    unhides "pixmap" property for a given class.
+
+  See StdWidgetFactory::StdWidgetFactory() for properties like
+  "Line:orientationSelectionPopup:horizontalIcon".
+
+  \n\n
   See the standard factories in formeditor/factories for an example of factories,
   and how to deal with complex widgets (eg tabwidget).
   */
@@ -210,6 +258,15 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 {
 	Q_OBJECT
 	public:
+		//! Options used in createWidget()
+		enum CreateWidgetOptions { 
+			AnyOrientation = 1, //!< any orientation hint
+			HorizontalOrientation = 2,  //!< horizontal orientation hint
+			VerticalOrientation = 4, //!< vertical orientation hint
+			DesignViewMode = 8, //!< create widget in design view mode, otherwise preview mode
+			DefaultOptions = AnyOrientation | DesignViewMode
+		};
+
 		WidgetFactory(QObject *parent=0, const char *name=0);
 		virtual ~WidgetFactory();
 
@@ -227,18 +284,22 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 		 */
 		const WidgetInfo::Dict classes() const { return m_classesByName; }
 
-		/*!
-		 * Creates a widget (and if needed a \ref Container)
+		/**
+		 * Creates a widget (and if needed a KFormDesigner::Container)
 		 * \return the created widget
 		 * \param classname the classname of the widget, which should get created
 		 * \param parent the parent for the created widget
 		 * \param name the name of the created widget
-		 * \param toplevel the toplevel Container (if a container should get created)
+		 * \param container the toplevel Container (if a container should get created)
+		 * \param options options for the created widget: orientation and view mode (see CreateWidgetOptions)
 		 */
-		virtual QWidget* create(const QCString &classname, QWidget *parent, const char *name,
-					 KFormDesigner::Container *container)=0;
+		virtual QWidget* createWidget(const QCString &classname, QWidget *parent, const char *name,
+			KFormDesigner::Container *container, 
+			int options = DefaultOptions) = 0;
 
-		virtual void createCustomActions(KActionCollection* ) {};
+		/*! Creates custom actions. Reimplement this if you need to add some 
+		 actions coming from the factory. */
+		virtual void createCustomActions(KActionCollection *col) { Q_UNUSED(col); };
 
 		/*! This function can be used to add custom items in widget \a w context
 		menu \a menu. */
@@ -280,8 +341,8 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 		then multiple widgets of the same class are selected, and you should
 		only show properties shared by widgets (eg font, color). By default,
 		all properties are shown if multiple == true, and none if multiple == false. */
-		bool isPropertyVisible(const QCString &classname, QWidget *w, 
-			const QCString &property, bool multiple);
+		bool isPropertyVisible(const QCString &classname, QWidget *w,
+			const QCString &property, bool multiple, bool isTopLevel);
 
 		/*! You need to return here a list of the properties that should automatically be saved
 		for a widget belonging to \a classname, and your custom properties (eg "text"
@@ -295,24 +356,39 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 		/*! \return The i18n'ed name of the property's value whose name is \a name. */
 		inline QString propertyDescForValue(const QCString &name) { return m_propValDesc[name]; };
 
-		/*! This method is called after ObjectPropertyBuffer was filled with properties 
+		/*! This method is called after WidgetPropertySet was filled with properties
 		 of a widget \a w, of class defined by \a info.
 		 Default implementation does nothing.
-		 Implement this if you need to set options for properties within the buffer \a buf. */
-		virtual void setPropertyOptions( KexiPropertyBuffer& buf, const WidgetInfo& info, QWidget *w ) {}
+		 Implement this if you need to set options for properties within the set \a buf. */
+		virtual void setPropertyOptions( WidgetPropertySet& buf, const WidgetInfo& info, QWidget *w );
+
+		/*! \return internal property \a property for a class \a classname.
+		 Internal properties are not stored within objects, but can be just provided
+		 to describe classes' details. */
+		inline QString internalProperty(const QCString& classname, const QCString& property) const {
+			return m_internalProp[classname+":"+property];
+		}
 
 	protected:
-		virtual bool isPropertyVisibleInternal(const QCString &classname, QWidget *w, 
-			const QCString &property) { return false; }
+		/*! This function is called when we want to know whether the property should be visible.
+		 Implement it in the factory; don't forget to call implementation in the superclass. 
+		 Default implementation hides "caption", "icon", "sizeIncrement" and "iconText" properties. */
+		virtual bool isPropertyVisibleInternal(const QCString &classname, QWidget *w,
+			const QCString &property, bool isTopLevel);
+
+		/*! Sometimes property sets should be reloaded when a given property value changed.
+		 Implement it in the factory. Default implementation always returns false. */
+		virtual bool propertySetShouldBeReloadedAfterPropertyChange(const QCString& classname, QWidget *w, 
+			const QCString& property);
 
 		/*! This function creates a KLineEdit to input some text and edit a widget's contents.
 		 This can be used in startEditing(). \a text is the text to display by default
 		  in the line edit, \a w is the edited widget, \a geometry is the geometry the new line
-		   edit should have, and \a align is Qt::AlignmentFlags of the new line edit.
-		 */
+		   edit should have, and \a align is Qt::AlignmentFlags of the new line edit. */
 		void createEditor(const QCString &classname, const QString &text,
 			QWidget *w, Container *container, QRect geometry,
-			int align,  bool useFrame=false, BackgroundMode background = Qt::NoBackground);
+			int align, bool useFrame=false, bool multiLine = false,
+			BackgroundMode background = Qt::NoBackground);
 
 		/*! This function provides a simple editing mode : it justs disable event filtering
 		for the widget, and it install it again when
@@ -342,10 +418,11 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 		/*! This function is used to modify a property of a widget (eg after editing it).
 		Please use it instead of w->setProperty() to allow sync inside PropertyEditor.
 		*/
-		void changeProperty(const char *name, const QVariant &value, Container *container);
+		void changeProperty(const char *name, const QVariant &value, Form *form);
 
-		/*! This function is called when the widget is resized, and the editor size needs to be updated. */
-		virtual void resizeEditor(QWidget *widget, const QCString &classname);
+		/*! This function is called when the widget is resized,
+		 and the \a editor size needs to be updated. */
+		virtual void resizeEditor(QWidget *editor, QWidget *widget, const QCString &classname);
 
 //		/*! Adds the i18n'ed description of a property, which will be shown in PropertyEditor. */
 //		void  addPropertyDescription(Container *container, const char *prop, const QString &desc);
@@ -358,9 +435,15 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 		 to load factories in proper order. */
 		bool inheritsFactories();
 
+	public slots:
+
+		/*! @internal. This slot is called when the editor has lost focus or the user pressed Enter.
+		It destroys the editor or installs again the event filter on the widget. */
+		void resetEditor();
+
 	protected slots:
 		/*!
-		Default implementation will change property "text".
+		Default implementation changes "text" property.
 		You have to reimplement this function for editing inside the Form to work if your widget's
 		property you want to change isn't named "text".
 		This slot is called when the line edit text changes, and you have to make
@@ -372,22 +455,30 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 
 		void slotTextChanged();
 
-		/*! This slot is called when the editor has lost focus or the user pressed Enter.
-		It destroys the editor or installs again the event filter on the widget. */
-		void resetEditor();
-
 		/*! This slot is called when the editor is destroyed.*/
 		void editorDeleted();
 		void widgetDestroyed();
 
 	protected:
-		QGuardedPtr<QWidget> m_widget;
+		QString editorText() const;
+		void setEditorText(const QString& text);
+		void setEditor(QWidget *widget, QWidget *editor);
+		QWidget *editor(QWidget *widget) const;
+		void setWidget(QWidget *widget, Container *container);
+		QWidget *widget() const;
+
+		/*! Assigns \a value for internal property \a property for a class \a classname.
+		 Internal properties are not stored within objects, but can be provided
+		 to describe classes' details. */
+		void setInternalProperty(const QCString& classname, const QCString& property, const QString& value);
+
+		WidgetLibrary *m_library;
 		QCString m_editedWidgetClass;
-#ifdef KEXI_KTEXTEDIT
-		QGuardedPtr<KTextEdit>  m_editor;
-#else
-		QGuardedPtr<KLineEdit>  m_editor;
-#endif
+//#ifdef KEXI_KTEXTEDIT
+//		QGuardedPtr<KTextEdit>  m_editor;
+//#else
+//		QGuardedPtr<KLineEdit>  m_editor;
+//#endif
 		QString m_firstText;
 		QGuardedPtr<ResizeHandleSet> m_handles;
 		QGuardedPtr<Container> m_container;
@@ -398,13 +489,30 @@ class KFORMEDITOR_EXPORT WidgetFactory : public QObject
 		//! i18n stuff
 		QMap<QCString, QString> m_propDesc;
 		QMap<QCString, QString> m_propValDesc;
+		//! internal properties
+		QMap<QCString, QString> m_internalProp;
 
-		/*! flag useful to decide whether to hide some properties. 
+		/*! flag useful to decide whether to hide some properties.
 		 It's value is inherited from WidgetLibrary. */
-		bool m_showAdvancedProperties; 
+		bool m_showAdvancedProperties;
+
+		/*! Contains name of an XMLGUI file providing toolbar buttons 
+		 (and menu items in the future?) for the factory. 
+		 Can be empty, e.g. for the main factory which has XMLGUI defined in the shell window itself
+		 (e.g. kexiformpartinstui.rc for Kexi Forms). This name is set in WidgetLibrary::loadFactories() */
+		QString m_xmlGUIFileName;
+
+		KXMLGUIClient *m_guiClient;
+
+		QGuardedPtr<QWidget> m_widget;
+		QGuardedPtr<QWidget> m_editor;
 
 	friend class WidgetLibrary;
 };
 
+//! macro to declare KFormDesigner-compatible widget factory as a KDE Component factory
+#define KFORMDESIGNER_WIDGET_FACTORY(factoryClassName, libraryName) \
+	K_EXPORT_COMPONENT_FACTORY(kformdesigner_ ## libraryName, KGenericFactory<factoryClassName>("kformdesigner_" # libraryName))
+
 }
 #endif
