@@ -155,6 +155,17 @@
 # endif
 #endif
 
+/* temporary */
+#ifndef KOMACRO_EXPORT
+# ifdef MAKE_KOMACRO_LIB
+#  define KOMACRO_EXPORT KDE_EXPORT
+# elif defined(KDE_MAKE_LIB)
+#  define KOMACRO_EXPORT KDE_IMPORT
+# else
+#  define KOMACRO_EXPORT
+# endif
+#endif
+
 /* additional default options */
 #ifndef KEXI_NO_CTXT_HELP
 # define KEXI_NO_CTXT_HELP
@@ -172,7 +183,6 @@
 # define KEXI_STARTUP_SHOW_TEMPLATES 
 # define KEXI_STARTUP_SHOW_RECENT
 # define KEXI_REPORTS_SUPPORT
-# define KEXI_NO_CSV_IMPORT
 */
 # define KEXI_NO_UNFINISHED
 # define KEXI_FORMS_SUPPORT
