@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -39,13 +39,6 @@ namespace KexiPart {
 	class Part;
 }
 
-//! @internal
-enum PrintActionType {
-	PrintItem,
-	PreviewItem,
-	PageSetupForItem
-};
-
 /**
  * @short Kexi's main window implementation
  */
@@ -76,19 +69,24 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		 \return false if doc couldn't be raised or isn't opened. */
 		bool activateWindow(int id);
 
-		/*! Like above, using \a dlg passed explicity. Above method just calls this one. */
+		/*! Like above, using \a dlg passed explicitly. Above method just calls this one. */
 		bool activateWindow(KexiDialogBase *dlg);
 
-//		void startup(KexiProjectData* pdata);
 		/*! Performs startup actions. \return false if application should exit immediately
 		 with an error status. */
 		tristate startup();
 
-		/*! \return true if this window is in the Final Mode. */
-		bool inFinalMode() const;
+		/*! \return true if the application window is in the User Mode. */
+		virtual bool userMode() const;
+
+		/*! \return true if opening of item \a item in \a viewMode mode is allowed. 
+		 userMode() is taken into account as well 
+		 as KexiPart::Part::supportedUserViewModes() for \a  item. */
+		bool openingAllowed(KexiPart::Item* item, int viewMode);
 
 		virtual bool eventFilter( QObject *obj, QEvent * e );
 
+		//! \return popup menu for \a popupName name.
 		virtual QPopupMenu* findPopupMenu(const char *popupName);
 
 		/*! Implemented for KexiMainWindow. */
@@ -98,12 +96,7 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		 Implemented for KexiMainWindow. */
 		virtual KexiDialogBase* currentDialog() const;
 
-		/**
-		 * @returns a pointer to the relation parts loads it if needed
-		 */
-//		KexiRelationPart	*relationPart();
-
-//TODO: move to kexiproject
+//! @todo move to kexiproject
 		/*! Generates ID for private "document" like Relations window.
 		 Private IDs are negative numbers (while ID regular part instance's IDs are >0)
 		 Private means that the object is not stored as-is in the project but is somewhat
@@ -136,17 +129,26 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		virtual void detachWindow(KMdiChildView *pWnd,bool bShow=true);
 		virtual void attachWindow(KMdiChildView *pWnd,bool bShow=true,bool bAutomaticResize=false);
 
+//! @todo move part of this to KexiProject, because currently KexiProject::openObject() allows multiple opens!
 		/*! Opens object pointed by \a item in a view \a viewMode.
 		 \a staticObjectArgs can be passed for static object 
 		 (only works when part for this item is of type KexiPart::StaticPart).
-		 \a openingCancelled is set to true is opening has been cancelled. */
+		 \a openingCancelled is set to true is opening has been cancelled. 
+		 \a errorMessage, if not 0, points to a string that can be set to error message
+		 if one encountered. */
 		virtual KexiDialogBase* openObject(KexiPart::Item *item, int viewMode, 
-			bool &openingCancelled, QMap<QString,QString>* staticObjectArgs = 0);
+			bool &openingCancelled, QMap<QString,QString>* staticObjectArgs = 0,
+			QString* errorMessage = 0);
 
 		//! For convenience
 		virtual KexiDialogBase* openObject(const QCString& mime, const QString& name, 
 			int viewMode, bool &openingCancelled, QMap<QString,QString>* staticObjectArgs = 0);
 
+		/*! Closes the object for \a item. 
+		 \return true on success (closing can be dealyed though), false on failure and cancelled 
+		 if the object has "opening" job assigned. */
+		virtual tristate closeObject(KexiPart::Item* item);
+
 		/*! Implemented for KexiMainWindow */
 		virtual tristate saveObject( KexiDialogBase *dlg,
 			const QString& messageWhenAskingForName = QString::null, bool dontAsk = false );
@@ -158,7 +160,7 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		/*! Implemented for KexiMainWindow */
 		virtual void highlightObject(const QCString& mime, const QCString& name);
 
-		/*! Opens project pointed by \a projectData, \return true on success.
+		/*! Opens project pointed by \a projectData.
 		 Application state (e.g. actions) is updated. 
 		 \a projectData is copied into a project structures. 
 		 \return true on success */
@@ -175,7 +177,8 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		  'kexi --skip-dialog file.kexic' is executed (or the connection is opened 
 		  directly if there's no porject opened in the current Kexi main window. */
 		tristate openProject(const QString& aFileName, KexiDB::ConnectionData *cdata, 
-			const QString& dbName = QString::null);
+			const QString& dbName = QString::null,
+			const QValueList<KexiProjectData::ObjectInfo>& autoopenObjects = QValueList<KexiProjectData::ObjectInfo>());
 
 		/*! Helper. Opens project pointed by \a aFileName.
 		 Like above but \a fileNameForConnectionData can be passed instead of 
@@ -186,22 +189,44 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		tristate openProject(const QString& aFileName, 
 			const QString& fileNameForConnectionData, const QString& dbName = QString::null);
 
+		/*! Creates a new project usign template pointed by \a projectData.
+		 Application state (e.g. actions) is updated. 
+		 New project data is copied into a project structures. 
+		 \return true on success */
+		tristate createProjectFromTemplate(const KexiProjectData& projectData);
+
 		/*! Closes current project, \return true on success.
 		 Application state (e.g. actions) is updated.
 		 \return true on success.
 		 If closing was cancelled by user, cancelled is returned. */
 		tristate closeProject();
 
+		//! Shows "print" dialog for \a item.
+		//! \return true on success.
+		virtual tristate printItem(KexiPart::Item* item);
+
+		//! Shows "print preview" dialog. 
+		//! \return true on success.
+		virtual tristate printPreviewForItem(KexiPart::Item* item);
+
+		//! Shows "page setup" dialog for \a item.
+		//! \return true on success and cancelled when the action was cancelled.
+		virtual tristate showPageSetupForItem(KexiPart::Item* item);
+
+		/*! Executes custom action for the main window, usually provided by a plugin. 
+		 Also used by KexiFormEventAction. */
+		virtual tristate executeCustomActionForObject(KexiPart::Item* item, const QString& actionName);
+
 	signals:
 		//! Emitted after opening a project, even after slotAutoOpenObjectsLater().
 		void projectOpened();
 
 	protected:
-		/*! Initialises final mode: constructs window according to kexi__final database
+		/*! Initialises the User Mode: constructs window according to kexi__final database
 		 and loads the specified part.
 		 \return true on success or false if e.g. kexi__final does not exist
 		 or a fatal exception happened */
-		bool initFinalMode(KexiProjectData *projectData);
+		bool initUserMode(KexiProjectData *projectData);
 
 		/*!
 		 Creates navigator (if it's not yet created),
@@ -339,7 +364,16 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		//! For convenience
 		KexiDialogBase* openObjectFromNavigator(KexiPart::Item* item, int viewMode);
 
-		bool newObject( KexiPart::Info *info );
+		/*! Creates new object of type defined by \a info part info. 
+		 \a openingCancelled is set to true is opening has been cancelled. 
+		 \return true on success. */
+		virtual bool newObject( KexiPart::Info *info, bool& openingCancelled );
+
+		//! For convenience
+		bool newObject( KexiPart::Info *info ) {
+			bool openingCancelled;
+			return newObject(info, openingCancelled);
+		}
 
 		//! For convenience
 		KexiDialogBase* openObject(KexiPart::Item *item, int viewMode, 
@@ -391,6 +425,14 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		void slotProjectQuit();
 		void slotEditPasteSpecialDataTable();
 		void slotEditCopySpecialDataTable();
+		void slotEditFind();
+		void slotEditFind(bool next); //!< helper
+		void slotEditFindNext();
+		void slotEditFindPrevious();
+		void slotEditReplace(bool all); //!< helper
+		void slotEditReplace();
+		void slotEditReplaceNext();
+		void slotEditReplaceAll();
 		void slotViewNavigator();
 		void slotViewMainArea();
 		void slotViewPropertyEditor();
@@ -453,11 +495,14 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		tristate executeItem(KexiPart::Item* item);
 
 		//! Shows "exports as data table" dialog for \a item.
-		void exportItemAsDataTable(KexiPart::Item* item);
+		tristate exportItemAsDataTable(KexiPart::Item* item);
+
+		//! Shows "copy special as data table" dialog for \a item.
+		tristate copyItemToClipboardAsDataTable(KexiPart::Item* item);
 
 		//! Shows "print" dialog for \a item.
 		//! \return true on success.
-		bool printItem(KexiPart::Item* item, const QString& titleText = QString::null);
+		bool printItem(KexiPart::Item* item, const QString& titleText);
 
 		//! Shows "print" dialog for \a item and \a settings.
 		//! \return true on success.
@@ -468,24 +513,20 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		 The preview dialog is cached, so \a reload == true is sometimes needed 
 		 if data or print settings have changed in the meantime.
 		 \return true on success. */
-		bool printPreviewForItem(KexiPart::Item* item, const QString& titleText = QString::null, 
-			bool reload = false);
+		bool printPreviewForItem(KexiPart::Item* item, const QString& titleText, 
+			bool reload);
 
-		/*! Shows "print preview" dialog for \a item and \a settings. 
-		 \return true on success. */
+		//! Shows "print preview" dialog. 
+		//! \return true on success.
 		bool printPreviewForItem(KexiPart::Item* item, const KexiSimplePrintingSettings& settings, 
 			const QString& titleText = QString::null, bool reload = false);
 
-		//! Shows "page setup" dialog for \a item.
-		//! \return true on success and cancelled when the action was cancelled.
-		tristate pageSetupForItem(KexiPart::Item* item);
-
-		//! Helper for printItem() and printPreviewForItem()
-		//! \return true on success and cancelled when the action was cancelled.
+		/*! Implemented for KexiMainWindow. Helper for printItem() and printPreviewForItem().
+		 Also used by KexiFormEventAction.
+		 \return true on success and cancelled when the action was cancelled. */
 		tristate printActionForItem(KexiPart::Item* item, PrintActionType action);
 
 	private:
-
 		class MessageHandler;
 		class Private;
 		Private *d;
