@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include "tool_text.h"
 
@@ -23,9 +23,9 @@
 #include <kiconloader.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
-#include <koPoint.h>
+#include <KoPoint.h>
 #include <klocale.h>
-#include <kozoomhandler.h>
+#include <KoZoomHandler.h>
 #include <kinputdialog.h>
 
 #include "kivio_view.h"
@@ -43,6 +43,7 @@
 #include "kivio_command.h"
 #include "kivio_pluginmanager.h"
 #include "mousetoolaction.h"
+#include "stenciltexteditor.h"
 
 
 TextTool::TextTool( KivioView* parent ) : Kivio::MouseTool(parent, "Text Mouse Tool")
@@ -257,6 +258,7 @@ void TextTool::applyToolAction(QPtrList<KivioStencil>* stencils)
   while(stencil) {
     if(stencil->hasTextBox()) {
       ok = true;
+      break;
     }
 
     stencil = stencils->next();
@@ -266,39 +268,81 @@ void TextTool::applyToolAction(QPtrList<KivioStencil>* stencils)
     return;
   }
 
-  stencil = stencils->first();
-  QString text = KInputDialog::getMultiLineText(i18n("Edit Text"), QString::null,
-      stencil->text(), &ok, view());
+  Kivio::StencilTextEditor editor(i18n("Edit Text"), view(), "StencilTextEditor");
+  editor.setFont(stencil->textFont());
+  editor.setFontColor(stencil->textColor());
+  editor.setBackgroundColor(stencil->bgColor());
+  editor.setText(stencil->text());
+  editor.setHorizontalAlign(static_cast<Qt::AlignmentFlags>(stencil->hTextAlign()));
+  editor.setVerticalAlign(static_cast<Qt::AlignmentFlags>(stencil->vTextAlign()));
 
-  if(!ok) {
-    return;
-  }
+  if(editor.exec() == QDialog::Accepted) {
+    KMacroCommand* macroCmd = new KMacroCommand(i18n("Change Stencil Text and Formatting"));
+    bool changed = false;
+    QString text = editor.text();
+    QFont font = editor.font();
+    QColor textColor = editor.fontColor();
+    int halignment = editor.horizontalAlignment();
+    int valignment = editor.verticalAlignment();
+    bool changeFont = (stencil->textFont() != font);
+    bool changeTextColor = (stencil->textColor() != textColor);
+    bool changeHAlignment = (stencil->hTextAlign() != halignment);
+    bool changeVAlignment = (stencil->vTextAlign() != valignment);
 
-  KMacroCommand *macro = new KMacroCommand( i18n("Change Stencil Text"));
-  bool createMacro = false;
-  KivioDoc* doc = view()->doc();
-  KivioPage* page = view()->activePage();
 
-  while( stencil )
-  {
-    if(stencil->text() != text)
+    while( stencil )
     {
-      KivioChangeStencilTextCommand *cmd = new KivioChangeStencilTextCommand(i18n("Change Stencil Text"),
-        stencil, stencil->text(), text, page);
-      macro->addCommand( cmd);
-      stencil->setText( text );
-      createMacro=true;
+      if(stencil->text() != text)
+      {
+        KivioChangeStencilTextCommand *cmd = new KivioChangeStencilTextCommand(i18n("Change Stencil Text"),
+            stencil, stencil->text(), text, view()->activePage());
+        stencil->setText(text);
+        macroCmd->addCommand(cmd);
+        changed = true;
+      }
+
+      if(changeFont && (stencil->textFont() != font)) {
+        KivioChangeStencilFontCommand* cmd = new KivioChangeStencilFontCommand(i18n("Change Stencil Font"),
+            view()->activePage(), stencil, stencil->textFont(), font);
+        stencil->setTextFont(font);
+        macroCmd->addCommand(cmd);
+        changed = true;
+      }
+
+      if(changeTextColor && (stencil->textColor() != textColor)) {
+        KivioChangeStencilColorCommand* cmd = new KivioChangeStencilColorCommand(i18n("Change Stencil Text Color"),
+            view()->activePage(), stencil, stencil->textColor(), textColor, KivioChangeStencilColorCommand::CT_TEXTCOLOR);
+        stencil->setTextColor(textColor);
+        macroCmd->addCommand(cmd);
+        changed = true;
+      }
+
+      if(changeHAlignment && (stencil->hTextAlign() != halignment)) {
+        KivioChangeStencilHAlignmentCommand* cmd = new KivioChangeStencilHAlignmentCommand(
+            i18n("Change Stencil Horizontal Alignment"), view()->activePage(), stencil, stencil->hTextAlign(), halignment);
+        stencil->setHTextAlign(halignment);
+        macroCmd->addCommand(cmd);
+        changed = true;
+      }
+
+      if(changeVAlignment && (stencil->vTextAlign() != valignment)) {
+        KivioChangeStencilVAlignmentCommand* cmd = new KivioChangeStencilVAlignmentCommand(
+            i18n("Change Stencil Vertical Alignment"), view()->activePage(), stencil, stencil->vTextAlign(), valignment);
+        stencil->setVTextAlign(valignment);
+        macroCmd->addCommand(cmd);
+        changed = true;
+      }
+
+      stencil = stencils->next();
+    }
+
+    if(changed) {
+      view()->doc()->addCommand(macroCmd);
+      view()->doc()->updateView(view()->activePage());
+    } else {
+      delete macroCmd;
     }
-    
-    stencil = stencils->next();
   }
-  
-  if(createMacro)
-    doc->addCommand(macro);
-  else
-    delete macro;
-  
-  doc->updateView(page);
 }
 
 void TextTool::applyToolAction(KivioStencil* stencil, const KoPoint& pos)
@@ -313,26 +357,78 @@ void TextTool::applyToolAction(KivioStencil* stencil, const KoPoint& pos)
     return;
   }
 
-  bool ok = false;
-  QString text = KInputDialog::getMultiLineText(i18n("Edit Text"), QString::null,
-      stencil->text(name), &ok, view());
+  Kivio::StencilTextEditor editor(i18n("Edit Text"), view(), "StencilTextEditor");
+  editor.setFont(stencil->textFont(name));
+  editor.setFontColor(stencil->textColor(name));
+  editor.setBackgroundColor(stencil->bgColor());
+  editor.setText(stencil->text(name));
+  editor.setHorizontalAlign(static_cast<Qt::AlignmentFlags>(stencil->hTextAlign(name)));
+  editor.setVerticalAlign(static_cast<Qt::AlignmentFlags>(stencil->vTextAlign(name)));
 
-  if(!ok) {
-    return;
+  if(editor.exec() == QDialog::Accepted) {
+    KMacroCommand* macroCmd = new KMacroCommand(i18n("Change Stencil Text and Formatting"));
+    bool changed = false;
+    QString text = editor.text();
+
+    if(stencil->text(name) != text)
+    {
+      KivioChangeStencilTextCommand *cmd = new KivioChangeStencilTextCommand(i18n("Change Stencil Text"),
+          stencil, stencil->text(name), text, view()->activePage(), name);
+      stencil->setText(text, name);
+      macroCmd->addCommand(cmd);
+      changed = true;
+    }
+
+    QFont font = editor.font();
+
+    if(stencil->textFont(name) != font) {
+      KivioChangeStencilFontCommand* cmd = new KivioChangeStencilFontCommand(i18n("Change Stencil Font"),
+          view()->activePage(), stencil, stencil->textFont(name), font, name);
+      stencil->setTextFont(name, font);
+      macroCmd->addCommand(cmd);
+      changed = true;
+    }
+
+    QColor textColor = editor.fontColor();
+
+    if(stencil->textColor(name) != textColor) {
+      KivioChangeStencilColorCommand* cmd = new KivioChangeStencilColorCommand(i18n("Change Stencil Text Color"),
+          view()->activePage(), stencil, stencil->textColor(name), textColor,
+          KivioChangeStencilColorCommand::CT_TEXTCOLOR, name);
+      stencil->setTextColor(name, textColor);
+      macroCmd->addCommand(cmd);
+      changed = true;
+    }
+
+    int halignment = editor.horizontalAlignment();
+
+    if(stencil->hTextAlign(name) != halignment) {
+      KivioChangeStencilHAlignmentCommand* cmd = new KivioChangeStencilHAlignmentCommand(
+          i18n("Change Stencil Horizontal Alignment"), view()->activePage(), stencil,
+          stencil->hTextAlign(name), halignment, name);
+      stencil->setHTextAlign(name, halignment);
+      macroCmd->addCommand(cmd);
+      changed = true;
+    }
+
+    int valignment = editor.verticalAlignment();
+
+    if(stencil->vTextAlign(name) != valignment) {
+      KivioChangeStencilVAlignmentCommand* cmd = new KivioChangeStencilVAlignmentCommand(
+          i18n("Change Stencil Vertical Alignment"), view()->activePage(), stencil,
+      stencil->vTextAlign(name), valignment, name);
+      stencil->setVTextAlign(name, valignment);
+      macroCmd->addCommand(cmd);
+      changed = true;
+    }
+
+    if(changed) {
+      view()->doc()->addCommand(macroCmd);
+      view()->doc()->updateView(view()->activePage());
+    } else {
+      delete macroCmd;
+    }
   }
-
-  KivioDoc* doc = view()->doc();
-  KivioPage* page = view()->activePage();
-
-  if(stencil->text(name) != text)
-  {
-    KivioChangeStencilTextCommand *cmd = new KivioChangeStencilTextCommand(i18n("Change Stencil Text"),
-      stencil, stencil->text(name), text, page);
-    stencil->setText(text, name);
-    doc->addCommand(cmd);
-  }
-
-  doc->updateView(page);
 }
 
 void TextTool::makePermanent()
