@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 1999 - 2003 The KSpread Team
-                             www.koffice.org/kspread
+   Copyright 1998, 1999 Torben Weis <weis@kde.org>
+   Copyright 1999- 2003 The KSpread Team
+                        www.koffice.org/kspread
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -15,36 +15,39 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <float.h>
 
 #include "kspread_cell.h"
-#include "kspread_condition.h"
 #include "kspread_sheet.h"
 #include "kspread_doc.h"
 #include "kspread_style.h"
 #include "kspread_style_manager.h"
 #include "kspread_util.h"
 
-#include <koGenStyles.h>
+#include <KoGenStyles.h>
 
-#include <koxmlwriter.h>
-#include <koxmlns.h>
+#include <KoXmlWriter.h>
+#include <KoXmlNS.h>
 #include <kdebug.h>
 #include <qdom.h>
 #include <qbuffer.h>
 
-KSpreadConditional::KSpreadConditional():
+#include "kspread_condition.h"
+
+using namespace KSpread;
+
+Conditional::Conditional():
   val1( 0.0 ), val2( 0.0 ), strVal1( 0 ), strVal2( 0 ),
   colorcond( 0 ), fontcond( 0 ), styleName( 0 ),
   style( 0 ), cond( None )
 {
 }
 
-KSpreadConditional::~KSpreadConditional()
+Conditional::~Conditional()
 {
   delete strVal1;
   delete strVal2;
@@ -53,12 +56,12 @@ KSpreadConditional::~KSpreadConditional()
   delete styleName;
 }
 
-KSpreadConditional::KSpreadConditional( const KSpreadConditional& c )
+Conditional::Conditional( const Conditional& c )
 {
   operator=( c );
 }
 
-KSpreadConditional& KSpreadConditional::operator=( const KSpreadConditional& d )
+Conditional& Conditional::operator=( const Conditional& d )
 {
   strVal1 = d.strVal1 ? new QString( *d.strVal1 ) : 0;
   strVal2 = d.strVal2 ? new QString( *d.strVal2 ) : 0;
@@ -73,21 +76,37 @@ KSpreadConditional& KSpreadConditional::operator=( const KSpreadConditional& d )
   return *this;
 }
 
+bool Conditional::operator==(const Conditional& other) const
+{
+  if ( cond == other.cond &&
+       val1 == other.val1 &&
+       val2 == other.val2 &&
+       *strVal1 == *other.strVal1 &&
+       *strVal2 == *other.strVal2 &&
+       *colorcond == *other.colorcond &&
+       *fontcond == *other.fontcond &&
+       *styleName == *other.styleName &&
+       *style == *other.style )
+  {
+    return true;
+  }
+  return false;
+}
 
-KSpreadConditions::KSpreadConditions( const KSpreadCell * ownerCell )
+Conditions::Conditions( const Cell * ownerCell )
   : m_cell( ownerCell ), m_matchedStyle( 0 )
 {
   Q_ASSERT( ownerCell != NULL );
 }
 
-KSpreadConditions::~KSpreadConditions()
+Conditions::~Conditions()
 {
   m_condList.clear();
 }
 
-void KSpreadConditions::checkMatches()
+void Conditions::checkMatches()
 {
-  KSpreadConditional condition;
+  Conditional condition;
 
   if ( currentCondition( condition ) )
     m_matchedStyle = condition.style;
@@ -95,29 +114,31 @@ void KSpreadConditions::checkMatches()
     m_matchedStyle = 0;
 }
 
-bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
+bool Conditions::currentCondition( Conditional & condition )
 {
   /* for now, the first condition that is true is the one that will be used */
 
-  QValueList<KSpreadConditional>::const_iterator it;
+  QValueList<Conditional>::const_iterator it;
   double value   = m_cell->value().asFloat();
-  QString strVal = m_cell->text();
+  QString strVal = m_cell->value().asString();
 
-  //  if ( m_cell->value().isNumber() && !m_cell->sheet()->getShowFormula())
-  //  {
 
   for ( it = m_condList.begin(); it != m_condList.end(); ++it )
   {
     condition = *it;
-    kdDebug()<<"*it :"<< *( ( *it ).styleName )<<endl;
-    kdDebug()<<"*it style :"<<(  *it ).style <<endl;
+
+//     if ( (*it).styleName )
+//         kdDebug()<<"*it :"<<  *( ( *it ).styleName ) <<endl;
+//
+//     kdDebug()<<"*it style :"<<(  *it ).style <<endl;
+
 
     if ( condition.strVal1 && m_cell->value().isNumber() )
       continue;
 
     switch ( condition.cond )
     {
-     case Equal:
+      case Conditional::Equal:
       if ( condition.strVal1 )
       {
         if ( strVal == *condition.strVal1 )
@@ -131,7 +152,7 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
       }
       break;
 
-     case Superior:
+      case Conditional::Superior:
       if ( condition.strVal1 )
       {
         if ( strVal > *condition.strVal1 )
@@ -144,7 +165,7 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
       }
       break;
 
-     case Inferior:
+      case Conditional::Inferior:
       if ( condition.strVal1 )
       {
         if ( strVal < *condition.strVal1 )
@@ -157,7 +178,7 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
       }
       break;
 
-     case SuperiorEqual :
+      case Conditional::SuperiorEqual :
       if ( condition.strVal1 )
       {
         if ( strVal >= *condition.strVal1 )
@@ -170,7 +191,7 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
       }
       break;
 
-     case InferiorEqual :
+      case Conditional::InferiorEqual :
       if ( condition.strVal1 )
       {
         if ( strVal <= *condition.strVal1 )
@@ -183,7 +204,7 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
       }
       break;
 
-     case Between :
+      case Conditional::Between :
       if ( condition.strVal1 && condition.strVal2 )
       {
         if ( strVal > *condition.strVal1 && strVal < *condition.strVal2 )
@@ -197,7 +218,7 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
       }
       break;
 
-     case Different :
+      case Conditional::Different :
       if ( condition.strVal1 && condition.strVal2 )
       {
         if ( strVal < *condition.strVal1 || strVal > *condition.strVal2 )
@@ -210,7 +231,7 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
         return true;
       }
       break;
-     case DifferentTo :
+      case Conditional::DifferentTo :
       if ( condition.strVal1 )
       {
         if ( strVal != *condition.strVal1 )
@@ -230,33 +251,33 @@ bool KSpreadConditions::currentCondition( KSpreadConditional & condition )
   return false;
 }
 
-QValueList<KSpreadConditional> KSpreadConditions::conditionList() const
+QValueList<Conditional> Conditions::conditionList() const
 {
   return m_condList;
 }
 
-void KSpreadConditions::setConditionList( const QValueList<KSpreadConditional> & list )
+void Conditions::setConditionList( const QValueList<Conditional> & list )
 {
   m_condList.clear();
 
-  QValueList<KSpreadConditional>::const_iterator it;
+  QValueList<Conditional>::const_iterator it;
   for ( it = list.begin(); it != list.end(); ++it )
   {
-    KSpreadConditional d = *it;
-    m_condList.append( KSpreadConditional( d ) );
+    Conditional d = *it;
+    m_condList.append( Conditional( d ) );
   }
 }
 
-void KSpreadConditions::saveOasisConditions( KoGenStyle &currentCellStyle )
+void Conditions::saveOasisConditions( KoGenStyle &currentCellStyle )
 {
     //todo fix me with kspread old format!!!
     if ( m_condList.isEmpty() )
         return;
-    QValueList<KSpreadConditional>::const_iterator it;
+    QValueList<Conditional>::const_iterator it;
     int i = 0;
     for ( it = m_condList.begin(); it != m_condList.end(); ++it, ++i )
     {
-        KSpreadConditional condition = *it;
+        Conditional condition = *it;
         //<style:map style:condition="cell-content()=45" style:apply-style-name="Default" style:base-cell-address="Sheet1.E10"/>
         QMap<QString, QString> map;
         map.insert( "style:condition", saveOasisConditionValue( condition ) );
@@ -266,51 +287,51 @@ void KSpreadConditions::saveOasisConditions( KoGenStyle &currentCellStyle )
     }
 }
 
-QString KSpreadConditions::saveOasisConditionValue( KSpreadConditional &condition)
+QString Conditions::saveOasisConditionValue( Conditional &condition)
 {
     //we can also compare text value.
     //todo adapt it.
     QString value;
     switch( condition.cond )
     {
-    case None:
+      case Conditional::None:
         break;
-    case Equal:
+      case Conditional::Equal:
         value="cell-content()=";
         if ( condition.strVal1 )
             value+=*condition.strVal1;
         else
             value+=QString::number( condition.val1 );
         break;
-    case Superior:
+      case Conditional::Superior:
         value="cell-content()>";
         if ( condition.strVal1 )
             value+=*condition.strVal1;
         else
             value+=QString::number( condition.val1 );
         break;
-    case Inferior:
+      case Conditional::Inferior:
         value="cell-content()<";
         if ( condition.strVal1 )
             value+=*condition.strVal1;
         else
             value+=QString::number( condition.val1 );
         break;
-    case SuperiorEqual:
+      case Conditional::SuperiorEqual:
         value="cell-content()>=";
         if ( condition.strVal1 )
             value+=*condition.strVal1;
         else
             value+=QString::number( condition.val1 );
         break;
-    case InferiorEqual:
+      case Conditional::InferiorEqual:
         value="cell-content()<=";
         if ( condition.strVal1 )
             value+=*condition.strVal1;
         else
             value+=QString::number( condition.val1 );
         break;
-    case Between:
+      case Conditional::Between:
         value="cell-content-is-between(";
         if ( condition.strVal1 )
         {
@@ -327,14 +348,14 @@ QString KSpreadConditions::saveOasisConditionValue( KSpreadConditional &conditio
         }
         value+=")";
         break;
-    case DifferentTo:
+      case Conditional::DifferentTo:
         value="cell-content()!="; //FIXME not good here !
         if ( condition.strVal1 )
             value+=*condition.strVal1;
         else
             value+=QString::number( condition.val1 );
         break;
-    case Different:
+      case Conditional::Different:
         value="cell-content-is-not-between(";
         if ( condition.strVal1 )
         {
@@ -356,17 +377,17 @@ QString KSpreadConditions::saveOasisConditionValue( KSpreadConditional &conditio
 }
 
 
-QDomElement KSpreadConditions::saveConditions( QDomDocument & doc ) const
+QDomElement Conditions::saveConditions( QDomDocument & doc ) const
 {
   QDomElement conditions = doc.createElement("condition");
-  QValueList<KSpreadConditional>::const_iterator it;
+  QValueList<Conditional>::const_iterator it;
   QDomElement child;
   int num = 0;
   QString name;
 
   for ( it = m_condList.begin(); it != m_condList.end(); ++it )
   {
-    KSpreadConditional condition = *it;
+    Conditional condition = *it;
 
     /* the name of the element will be "condition<n>"
      * This is unimportant now but in older versions three conditions were
@@ -416,24 +437,24 @@ QDomElement KSpreadConditions::saveConditions( QDomDocument & doc ) const
   }
 }
 
-void KSpreadConditions::loadOasisConditions( const QDomElement & element )
+void Conditions::loadOasisConditions( const QDomElement & element )
 {
-    kdDebug()<<"void KSpreadConditions::loadOasisConditions( const QDomElement & element )\n";
-    QDomElement elementItem( element );
-    KSpreadStyleManager * manager = m_cell->sheet()->doc()->styleManager();
+    kdDebug(36003) << "Loading conditional styles" << endl;
+    QDomNode node( element );
+    StyleManager * manager = m_cell->sheet()->doc()->styleManager();
 
-    while ( !elementItem.isNull() )
+    while ( !node.isNull() )
     {
-        kdDebug()<<"elementItem.tagName() :"<<elementItem.tagName()<<endl;
+        QDomElement elementItem = node.toElement();
         if ( elementItem.tagName()== "map" && elementItem.namespaceURI() == KoXmlNS::style  )
         {
             bool ok = true;
-            kdDebug()<<"elementItem.attribute(style:condition ) :"<<elementItem.attributeNS( KoXmlNS::style, "condition", QString::null )<<endl;
-            KSpreadConditional newCondition;
+            kdDebug(36003) << "\tcondition: "<< elementItem.attributeNS( KoXmlNS::style, "condition", QString::null )<<endl;
+            Conditional newCondition;
             loadOasisConditionValue( elementItem.attributeNS( KoXmlNS::style, "condition", QString::null ), newCondition );
             if ( elementItem.hasAttributeNS( KoXmlNS::style, "apply-style-name" ) )
             {
-                kdDebug()<<"elementItem.attribute( style:apply-style-name ) :"<<elementItem.attributeNS( KoXmlNS::style, "apply-style-name", QString::null )<<endl;
+                kdDebug(36003)<<"\tstyle: "<<elementItem.attributeNS( KoXmlNS::style, "apply-style-name", QString::null )<<endl;
                 newCondition.styleName = new QString( elementItem.attributeNS( KoXmlNS::style, "apply-style-name", QString::null ) );
                 newCondition.style = manager->style( *newCondition.styleName );
                 if ( !newCondition.style )
@@ -445,13 +466,13 @@ void KSpreadConditions::loadOasisConditions( const QDomElement & element )
             if ( ok )
                 m_condList.append( newCondition );
             else
-                kdDebug(36001) << "Error loading condition " << elementItem.nodeName()<< endl;
+                kdDebug(36003) << "Error loading condition " << elementItem.nodeName()<< endl;
         }
-        elementItem = elementItem.nextSibling().toElement();
+        node = node.nextSibling();
     }
 }
 
-void KSpreadConditions::loadOasisConditionValue( const QString &styleCondition, KSpreadConditional &newCondition )
+void Conditions::loadOasisConditionValue( const QString &styleCondition, Conditional &newCondition )
 {
     QString val( styleCondition );
     if ( val.contains( "cell-content()" ) )
@@ -467,7 +488,7 @@ void KSpreadConditions::loadOasisConditionValue( const QString &styleCondition,
         val = val.remove( ")" );
         QStringList listVal = QStringList::split( "," , val );
         loadOasisValidationValue( listVal, newCondition );
-        newCondition.cond = Between;
+        newCondition.cond = Conditional::Between;
     }
     if ( val.contains( "cell-content-is-not-between(" ) )
     {
@@ -475,49 +496,49 @@ void KSpreadConditions::loadOasisConditionValue( const QString &styleCondition,
         val = val.remove( ")" );
         QStringList listVal = QStringList::split( ",", val );
         loadOasisValidationValue( listVal,newCondition );
-        newCondition.cond = Different;
+        newCondition.cond = Conditional::Different;
     }
 
 }
 
 
-void KSpreadConditions::loadOasisCondition( QString &valExpression, KSpreadConditional &newCondition )
+void Conditions::loadOasisCondition( QString &valExpression, Conditional &newCondition )
 {
     QString value;
     if (valExpression.find( "<=" )==0 )
     {
         value = valExpression.remove( 0,2 );
-        newCondition.cond = InferiorEqual;
+        newCondition.cond = Conditional::InferiorEqual;
     }
     else if (valExpression.find( ">=" )==0 )
     {
         value = valExpression.remove( 0,2 );
-        newCondition.cond = SuperiorEqual;
+        newCondition.cond = Conditional::SuperiorEqual;
     }
     else if (valExpression.find( "!=" )==0 )
     {
         //add Differentto attribute
         value = valExpression.remove( 0,2 );
-        newCondition.cond = DifferentTo;
+        newCondition.cond = Conditional::DifferentTo;
     }
     else if ( valExpression.find( "<" )==0 )
     {
         value = valExpression.remove( 0,1 );
-        newCondition.cond = Inferior;
+        newCondition.cond = Conditional::Inferior;
     }
     else if(valExpression.find( ">" )==0 )
     {
         value = valExpression.remove( 0,1 );
-        newCondition.cond = Superior;
+        newCondition.cond = Conditional::Superior;
     }
     else if (valExpression.find( "=" )==0 )
     {
         value = valExpression.remove( 0,1 );
-        newCondition.cond = Equal;
+        newCondition.cond = Conditional::Equal;
     }
     else
         kdDebug()<<" I don't know how to parse it :"<<valExpression<<endl;
-    kdDebug()<<" value :"<<value<<endl;
+    kdDebug(36003) << "\tvalue: " << value << endl;
     bool ok = false;
     newCondition.val1 = value.toDouble(&ok);
     if ( !ok )
@@ -528,12 +549,11 @@ void KSpreadConditions::loadOasisCondition( QString &valExpression, KSpreadCondi
             newCondition.strVal1 = new QString( value );
             kdDebug()<<" Try to parse this value :"<<value<<endl;
         }
-
     }
 }
 
 
-void KSpreadConditions::loadOasisValidationValue( const QStringList &listVal, KSpreadConditional &newCondition )
+void Conditions::loadOasisValidationValue( const QStringList &listVal, Conditional &newCondition )
 {
     bool ok = false;
     kdDebug()<<" listVal[0] :"<<listVal[0]<<" listVal[1] :"<<listVal[1]<<endl;
@@ -562,12 +582,12 @@ void KSpreadConditions::loadOasisValidationValue( const QStringList &listVal, KS
 }
 
 
-void KSpreadConditions::loadConditions( const QDomElement & element )
+void Conditions::loadConditions( const QDomElement & element )
 {
   QDomNodeList nodeList = element.childNodes();
-  KSpreadConditional newCondition;
+  Conditional newCondition;
   bool ok;
-  KSpreadStyleManager * manager = m_cell->sheet()->doc()->styleManager();
+  StyleManager * manager = m_cell->sheet()->doc()->styleManager();
 
   for ( int i = 0; i < (int)(nodeList.length()); ++i )
   {
@@ -582,7 +602,7 @@ void KSpreadConditions::loadConditions( const QDomElement & element )
     ok = conditionElement.hasAttribute( "cond" );
 
     if ( ok )
-      newCondition.cond = (Conditional) conditionElement.attribute( "cond" ).toInt( &ok );
+      newCondition.cond = (Conditional::Type) conditionElement.attribute( "cond" ).toInt( &ok );
     else continue;
 
     if ( conditionElement.hasAttribute( "val1" ) )
@@ -626,3 +646,25 @@ void KSpreadConditions::loadConditions( const QDomElement & element )
     }
   }
 }
+
+bool Conditions::operator==( const Conditions& other ) const
+{
+  if ( !( *m_matchedStyle == *other.m_matchedStyle ) )
+    return false;
+  if ( m_condList.count() != other.m_condList.count() )
+    return false;
+  QValueList<Conditional>::ConstIterator end( m_condList.end() );
+  for ( QValueList<Conditional>::ConstIterator it( m_condList.begin() ); it != end; ++it )
+  {
+    bool found = false;
+    QValueList<Conditional>::ConstIterator otherEnd( other.m_condList.end() );
+    for ( QValueList<Conditional>::ConstIterator otherIt( other.m_condList.begin() ); otherIt != otherEnd; ++otherIt )
+    {
+      if ( (*it) == (*otherIt) )
+        found = true;
+    }
+    if ( !found )
+      return false;
+  }
+  return true;
+}
