@@ -2,18 +2,23 @@
 
 #include <qdom.h>
 
-KSpreadLocale::KSpreadLocale()
+using namespace KSpread;
+
+Locale::Locale()
 	: KLocale("kspread")
 {
 	insertCatalogue("koffice");
 }
 
-void KSpreadLocale::load( const QDomElement& element )
+void Locale::load( const QDomElement& element )
 {
     if ( element.hasAttribute( "weekStartsMonday" ) )
     {
 	QString c = element.attribute( "weekStartsMonday" );
-	setWeekStartsMonday( c != "False");
+        if ( c != "False")
+        {
+          setWeekStartDay( 1 /*Monday*/ );
+        }
     }
     if ( element.hasAttribute( "decimalSymbol" ) )
 	setDecimalSymbol( element.attribute( "decimalSymbol" ) );
@@ -53,11 +58,11 @@ void KSpreadLocale::load( const QDomElement& element )
 	setDateFormatShort( element.attribute( "dateFormatShort" ) );
 }
 
-QDomElement KSpreadLocale::save( QDomDocument& doc ) const
+QDomElement Locale::save( QDomDocument& doc ) const
 {
     QDomElement element = doc.createElement( "locale" );
 
-    element.setAttribute( "weekStartsMonday", weekStartsMonday() ? "True" : "False" );
+    element.setAttribute( "weekStartsMonday", (weekStartDay() == 1) ? "True" : "False" );
     element.setAttribute( "decimalSymbol", decimalSymbol() );
     element.setAttribute( "thousandsSeparator", thousandsSeparator() );
     element.setAttribute( "currencySymbol", currencySymbol() );
@@ -77,10 +82,10 @@ QDomElement KSpreadLocale::save( QDomDocument& doc ) const
     return element;
 }
 
-void KSpreadLocale::defaultSystemConfig( )
+void Locale::defaultSystemConfig( )
 {
     KLocale locale("kspread");
-    setWeekStartsMonday( locale.weekStartsMonday());
+    setWeekStartDay( locale.weekStartDay() );
     setDecimalSymbol( locale.decimalSymbol());
     setThousandsSeparator( locale.thousandsSeparator() );
     setCurrencySymbol( locale.currencySymbol() );
