@@ -83,33 +83,33 @@ class KPSheetSelectPage : public KPrintDialogPage
   public:
     KPSheetSelectPage( QWidget *parent = 0 );
 //     ~KPSheetSelectPage();
-    
+
 //     //reimplement virtual functions
     /**
      * @see printOptionPrefix()
      */
     void getOptions( QMap<QString,QString>& opts, bool incldef = false );
-    
+
     /**
      * @see printOptionPrefix()
      */
     void setOptions( const QMap<QString,QString>& opts );
-    
+
     /**
      * @return false if no sheet is selected for printing.
      */
     bool isValid( QString& msg );
-    
+
     /**
      * @return list of sheets that will be printed, in correct order.
      */
     QStringList selectedSheets();
-    
+
     /**
      * Removes all sheets from the list of selected sheets.
      */
     void clearSelection();
-    
+
     /**
      * The print order of the sheets is stored in the option map,
      * using a prefix plus the index of the sheet, like the following:
@@ -122,25 +122,25 @@ class KPSheetSelectPage : public KPrintDialogPage
      * @return the string that is used in the printoption for given index
      */
     static QString printOptionForIndex(unsigned int index);
-    
+
     /**
      * @param prt the printer from which the options should be read.
      * @return list of sheets to print in correct order configured for given printer.
      */
     static QStringList selectedSheets(KPrinter &prt);
-    
+
   public slots:
-    
+
     /**
      * Inserts given sheet to the list of available sheets.
      */
     void prependAvailableSheet(const QString& sheetname);
-    
+
     /**
      * Inserts given sheet to the list of sheets for printing at the top.
      */
     void prependSelectedSheet(const QString& sheetname);
-    
+
   protected slots:
 
     // The following slots just implement the code for the buttons
@@ -149,14 +149,14 @@ class KPSheetSelectPage : public KPrintDialogPage
     void select();
     void remove();
     void removeAll();
-    
+
     void moveTop();
     void moveUp();
     void moveDown();
     void moveBottom();
-    
+
   private:
-  
+
     /**
      * The widget used, includes two lists of sheet names and
      * buttons to move sheets between and within the lists.
@@ -302,12 +302,6 @@ public:
 
     void initConfig();
 
-    /**
-     * Returns true if document is being loaded. It is useful to be checked for
-     * when doing view update.
-     */
-    bool isLoading() const;
-
 
     void initCalcMenu();
 
@@ -329,7 +323,7 @@ public:
      * They will be repainted on the next call to paintUpdates()
      */
     void markSelectionAsDirty();
-     
+
     /**
      * Repaint any cell with the paintDirty flag that is visible in this view
      */
@@ -344,14 +338,24 @@ public:
 
     bool showSheet(const QString& sheetName);
 
-    QPoint markerFromSheet( Sheet *_sheet ) const;
-    /*
-     * Save current sheet selection. Call when we change sheet, or save in oasis format
+    /**
+     * @return marker for @p sheet
+     */
+    QPoint markerFromSheet( Sheet* sheet ) const;
+
+    /**
+     * @return scroll offset for @p sheet
+     */
+    KoPoint offsetFromSheet( Sheet* sheet ) const;
+
+    /**
+     * Save current sheet selection.
+     * Call when we change sheet, or before save in OpenDocument format.
      */
     void saveCurrentSheetSelection();
 
     void deleteSelectedObjects();
-    
+
     /**
     * Returns the default color for highlighting cells and column / row headers
     */
@@ -510,7 +514,7 @@ public slots:
     void mergeCell();
     void mergeCellHorizontal();
     void mergeCellVertical();
-    
+
 
     /**
      * Breaks merged cell. Obviously this can be done only on merged cells.
@@ -661,6 +665,7 @@ public slots:
     void slotUpdateVBorder( Sheet *_sheet );
     void slotChangeSelection(const Region&);
     void slotChangeChoice(const Region&);
+    void slotScrollChoice(const Region&);
     void slotAddSheet( Sheet *_sheet );
     void slotUpdateChildGeometry( EmbeddedKOfficeObject *_child );
     void slotSheetRenamed( Sheet* sheet, const QString& old_name );
@@ -704,7 +709,7 @@ protected:
      *
      */
     KoPoint markerDocumentPosition();
-    
+
     /**
      * Activates the formula editor for the current cell.
      * This function is usually called if the user presses
@@ -732,8 +737,14 @@ private:
     bool spellSwitchToOtherSheet();
     void spellCleanup();
 
+    /**
+     * @return @c true if document is being loaded. It is useful to supress scrolling
+     * while the "View loading" process.
+     */
+    bool isLoading() const;
+
     Cell* nextFindValidCell( int col, int row );
-    
+
     friend class Private;
 };
 
