@@ -116,8 +116,8 @@ KWCanvas::KWCanvas(const QString& viewMode, QWidget *parent, KWDocument *d, KWGU
 
     viewport()->setFocusProxy( this );
     viewport()->setFocusPolicy( WheelFocus );
-    setFocus();
     setInputMethodEnabled( true );
+    setFocus();
     viewport()->installEventFilter( this );
     installEventFilter( this );
     KCursor::setAutoHideCursor( this, true, true );
@@ -146,7 +146,7 @@ KWCanvas::KWCanvas(const QString& viewMode, QWidget *parent, KWDocument *d, KWGU
         fs = m_doc->frameSetByName( fsName );
     if ( !fs )
         fs = m_doc->frameSet( 0 );
-    Q_ASSERT( fs );
+    //Q_ASSERT( fs ); // empty page template -> no fs
     if ( fs && fs->isVisible( m_viewMode ) ) {
         checkCurrentEdit( fs );
         KWTextFrameSetEdit* textedit = dynamic_cast<KWTextFrameSetEdit *>(m_currentFrameSetEdit);
@@ -455,7 +455,7 @@ void KWCanvas::contentsMousePressEvent( QMouseEvent *e )
 
             KWFrame * frame = view ? view->frame() : 0L;
             KWFrameSet * fs = frame ? frame->frameSet() : 0L;
-            if(fs->groupmanager())
+            if ( fs && fs->groupmanager() )
                 fs = fs->groupmanager();
             bool emitChanged = false;
             if ( fs )
@@ -1379,8 +1379,11 @@ void KWCanvas::terminateEditing( KWFrameSet *fs )
         terminateCurrentEdit();
     // Also deselect the frames from this frameset
     QPtrListIterator<KWFrame> frameIt = fs->frameIterator();
-    for ( ; frameIt.current(); ++frameIt )
-        m_frameViewManager->view(frameIt.current())->setSelected(false);
+    for ( ; frameIt.current(); ++frameIt ) {
+        KWFrameView* view = m_frameViewManager->view(frameIt.current());
+        Q_ASSERT(view);
+        if(view) view->setSelected(false);
+    }
 }
 
 KWTextFrameSetEdit* KWCanvas::currentTextEdit() const
@@ -1513,6 +1516,7 @@ void KWCanvas::contentsDropEvent( QDropEvent *e )
     } else if ( KURLDrag::canDecode( e ) ) {
 
         // TODO ask (with a popupmenu) between inserting a link and inserting the contents
+        // TODO fix khtml to export images when dragging an image+link (as it does when using "Copy")
 
         KURL::List lst;
         KURLDrag::decode( e, lst );
@@ -1555,10 +1559,16 @@ void KWCanvas::contentsDropEvent( QDropEvent *e )
 void KWCanvas::pasteImage( QMimeSource *e, const KoPoint &docPoint )
 {
     QImage i;
-    QImageDrag::decode(e, i);
+    if ( !QImageDrag::decode(e, i) ) {
+        kdWarning() << "Couldn't decode image" << endl;
+        return;
+    }
     KTempFile tmpFile( QString::null, ".png");
     tmpFile.setAutoDelete( true );
-    i.save(tmpFile.name(), "PNG");
+    if ( !i.save(tmpFile.name(), "PNG") ) {
+        kdWarning() << "Couldn't save image to " << tmpFile.name() << endl;
+        return;
+    }
     m_pixmapSize = i.size();
     // Prepare things for mrCreatePixmap
     KoPictureKey key;
@@ -1680,8 +1690,10 @@ void KWCanvas::updateRulerOffsets( int cx, int cy )
     // But we also need to offset to the current page, for the graduations
     QPoint pc = m_viewMode->pageCorner();
     //kdDebug() << "KWCanvas::updateRulerOffsets contentsX=" << cx << ", contentsY=" << cy << endl;
-    m_gui->getHorzRuler()->setOffset( cx - pc.x(), 0 );
-    m_gui->getVertRuler()->setOffset( 0, cy - pc.y() );
+    if (m_gui->getHorzRuler())
+        m_gui->getHorzRuler()->setOffset( cx - pc.x(), 0 );
+    if (m_gui->getVertRuler())
+        m_gui->getVertRuler()->setOffset( 0, cy - pc.y() );
 
 }
 
@@ -1944,7 +1956,12 @@ void KWCanvas::printRTDebug( int info )
 
 void KWCanvas::setXimPosition( int x, int y, int w, int h )
 {
-    QWidget::setMicroFocusHint( x - contentsX(), y - contentsY(), w, h );
+    /* Check for hasFocus() to avoid crashes in QXIMInputContext as in bug #123941.
+       This is only a workaround, the real problem might be in Qt. See also
+       http://lists.kde.org/?l=kde-core-devel&m=115770546313922&w=2 .
+    */
+    if (hasFocus())
+      QWidget::setMicroFocusHint( x - contentsX(), y - contentsY(), w, h );
 }
 
 void KWCanvas::inlinePictureStarted()
